@@ -401,12 +401,13 @@ typedef int ssl_algo_t;
  */
 #define SSL_OPT_NONE           (0)
 #define SSL_OPT_RELSET         (1<<0)
-#define SSL_OPT_COMPATENVVARS  (1<<1)
-#define SSL_OPT_EXPORTCERTDATA (1<<2)
-#define SSL_OPT_FAKEBASICAUTH  (1<<3)
-#define SSL_OPT_STRICTREQUIRE  (1<<4)
-#define SSL_OPT_OPTRENEGOTIATE (1<<5)
-#define SSL_OPT_ALL            (SSL_OPT_COMPATENVVAR|SSL_OPT_EXPORTCERTDATA|SSL_OPT_FAKEBASICAUTH|SSL_OPT_STRICTREQUIRE|SSL_OPT_OPTRENEGOTIATE)
+#define SSL_OPT_STDENVVARS     (1<<1)
+#define SSL_OPT_COMPATENVVARS  (1<<2)
+#define SSL_OPT_EXPORTCERTDATA (1<<3)
+#define SSL_OPT_FAKEBASICAUTH  (1<<4)
+#define SSL_OPT_STRICTREQUIRE  (1<<5)
+#define SSL_OPT_OPTRENEGOTIATE (1<<6)
+#define SSL_OPT_ALL            (SSL_OPT_STDENVVARS|SSL_OPT_COMPATENVVAR|SSL_OPT_EXPORTCERTDATA|SSL_OPT_FAKEBASICAUTH|SSL_OPT_STRICTREQUIRE|SSL_OPT_OPTRENEGOTIATE)
 typedef int ssl_opt_t;
 
 /*
